# LottoKit
Lotto Kit Package is A simple lottery analysis kit

```python
>>> from lottokit import Daletou
>>> t = Daletou()
>>> t.download_data()
>>> t.fetch_data()
>>> t.predict()
>>>
```

# Installing LottoKit and Supported Versions
LottoKit is available on PyPI:
```bash
python -m pip install lottokit
```
LottoKit officially supports Python 3.9+.

# API Reference and User Guide available on Read the Docs
[Documentation](http://python-lottokit.readthedocs.io)
